foo ::
  -- | Documentation
  Int ->
  Bool
foo _ = True

foo ::
  (Foo a) =>
  -- | Foo
  Int ->
  Int
foo ::
  (Foo a) =>
  -- | Foo
  Int ->
  Int
